<?php

/**
 * @file webform_chart_bundler_google_chart_api.module
 * This module provides a bundler between Webform Chart module and Google Chart API module.
 * It lets Webform Chart module use the Google Chart API to render the graphs.
 */
 
// ---------------------------------------------------------------------------------------
//            HOOKS IMPLEMENTATIONS
// ---------------------------------------------------------------------------------------

/**
 * Implemtation of hook_wfc_backend_help
 * Display the information about this bundler (when activated) in the charting configuration of a component.
 *
 * @return  array
 *   Returns an array which will be displayed as a lign in the help webform chart settings section.
 */
function webform_chart_bundler_google_chart_api_wfc_backend_help() {
  
  $help = array(
    t('<b>!chart_link</b> - a Drupal module that uses Google image charts API. (requires !chart_link, <b>!installed</b>)',
      array(  '!chart_link' =>l(t('Google Chart API'), 'http://drupal.org/project/chart'),
              '!installed' => module_exists('chart') ? t('Installed') : t('Not Installed'))),
  );
  return $help;
}

/**
 * Implements hook_wfc_backend()
 * Add an option in the backend select box for this option.
 * NOTE: the key value MUST be the name of this bundler module.
 * 
 * @return array
 *   Returns an array of key/value pairs to be rendered as select options
 */
function webform_chart_wfc_backend() {
  $backend = array();
  if (module_exists('chart')) {
    $backend['webform_chart_bundler_google_chart_api'] = t('Google Chart API');
    module_load_include('inc', 'webform_chart_bundler_google_chart_api', 'includes/chart');
  }
  return $backend;
}

/**
 * Implementation of hook_wfc_backend_configure().
 * Google Chart API, charts-specific configuration form that is called from webform_chart_form in webform_chart.admin.inc
 *
 * @return array
 *   Drupal API-formatted input elements
 */
function webform_chart_bundler_google_chart_api_wfc_backend_configure($default_values) {
  
  $types = chart_types();
  $items = array(
    'type' => array(
      '#type'           => 'select',
      '#title'          => t('Chart Type'),
      '#options'        => $types,
      '#default_value'  => $default_values['type'],
      '#description'    => t('Select a chart type for rendering webform charts'),
    ),
    'width' => array(
      '#type'           => 'textfield',
      '#title'          => t('Chart Width'),
      '#default_value'  => $default_values['width'],
      '#description'    => t('Enter the chart width as an integer'),
      '#size'           => 4
    ),
    'height' => array(
      '#type'           => 'textfield',
      '#title'          => t('Chart Height'),
      '#default_value'  => $default_values['height'],
      '#description'    => t('Enter the chart height as an integer'),
      '#size'           => 4
    ),

    'bar_size' => array(
      '#type'           => 'textfield',
      '#title'          => t('Chart Bar Width'),
      '#default_value'  => $default_values['bar_size'],
      '#description'    => t('Enter bar sizes as an integer (only applicable to bar-type charts)'),
      '#size'           => 4
    ),
    'bar_spacing' => array(
      '#type'           => 'textfield',
      '#title'          => t('Chart Bar Spacing'),
      '#default_value'  => $default_values['bar_spacing'],
      '#description'    => t('Enter bar spacing as an integer (only applicable to bar-type charts)'),
      '#size'           => 4
    ),
  );
  return $items;
}

/**
 * Implementation of hook_wfc_component_validate().
 *
 * Used to validate the component charting configuration form.
 * ie: used to validate the form defined in hook_wfc_backend_configure()
 */
function webform_chart_bundler_google_chart_api_wfc_component_validate(&$component) {  
}

/**
 * Implementation of hook_wfc_component_render().
 *
 * The main rendering function for charts that actually turns data into charts.
 */
function webform_chart_bundler_google_chart_api_wfc_component_render($item) {
  
  $output = '';

  if (array_key_exists('#data', $item)) {
    $item['#size'] = chart_size($item['width'], $item['height']);
    $output .=  '<div class="webform-chart-container" id="webform-chart-'.check_plain($item['#chart_id']).'">' .
      theme('chart', array('chart' => $item)) . "</div>";
  }

  return $output;
}